==> pierogi_1.1.26.tar.gz: pierogi-1.1.26/pirkeysetwidgetitem.cpp <==
//
// pirkeysetwidgetitem.cpp
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#include "pirkeysetwidgetitem.h"

PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  QString displayName,
  QString in,
  unsigned int i,
  PIRMakeName m)
  : QListWidgetItem(displayName),
    id(i),
    make(m),
    favorite(false),
    nicknameNotEmpty(false),
    internalName(in),
    tabBarName(Universal_Tabs),
    panelIndex(0)
{
}


PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  QString displayName,
  QString in,
  unsigned int i,
  PIRMakeName m,
  PIRDeviceTypeName t)
  : QListWidgetItem(displayName),
    id(i),
    make(m),
    deviceType(t),
    favorite(false),
    nicknameNotEmpty(false),
    internalName(in),
    tabBarName(Universal_Tabs),
    panelIndex(0)
{
}


PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  PIRKeysetWidgetItem *original)
  : QListWidgetItem(original->text()),
    id(original->getID()),
    make(original->getMake()),
    deviceType(original->getDeviceType()),
    favorite(original->isFavorite()),
    nicknameNotEmpty(original->hasNickname()),
    internalName(original->getInternalName()),
    tabBarName(original->getTabBarName()),
    panelIndex(original->getPanelIndex())
{
  if (nicknameNotEmpty)
  {
    nickname = original->getNickname();
  }
}


void PIRKeysetWidgetItem::setNickname(
  QString nn)
{
  nickname = nn;

  nicknameNotEmpty = !nn.isEmpty();
}

==> pierogi_1.1.35.tar.gz: pierogi-1.1.35/pirkeysetwidgetitem.cpp <==
//
// pirkeysetwidgetitem.cpp
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#include "pirkeysetwidgetitem.h"

PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  QString displayName,
  QString in,
  unsigned int i,
  PIRMakeName m)
  : QListWidgetItem(displayName),
    id(i),
    make(m),
    favorite(false),
    nicknameNotEmpty(false),
    internalName(in),
    panelTypes(TV_Panels),
    panelIndex(0)
{
}


PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  QString displayName,
  QString in,
  unsigned int i,
  PIRMakeName m,
  PIRDeviceTypeName t)
  : QListWidgetItem(displayName),
    id(i),
    make(m),
    deviceType(t),
    favorite(false),
    nicknameNotEmpty(false),
    internalName(in),
    panelTypes(TV_Panels),
    panelIndex(0)
{
}


PIRKeysetWidgetItem::PIRKeysetWidgetItem(
  PIRKeysetWidgetItem *original)
  : QListWidgetItem(original->text()),
    id(original->getID()),
    make(original->getMake()),
    deviceType(original->getDeviceType()),
    favorite(original->isFavorite()),
    nicknameNotEmpty(original->hasNickname()),
    internalName(original->getInternalName()),
    panelTypes(original->getPanelTypes()),
    panelIndex(original->getPanelIndex())
{
  if (nicknameNotEmpty)
  {
    nickname = original->getNickname();
  }
}


void PIRKeysetWidgetItem::setNickname(
  QString nn)
{
  nickname = nn;

  nicknameNotEmpty = !nn.isEmpty();
}
